@@ -1,4 +1,4 @@
-/* $Id: gucharmap-search-dialog.c,v 1.23 2006/02/20 02:00:01 behnam Exp $ */
+/* $Id: gucharmap-search-dialog.c 1493 2007-12-12 19:33:26Z chpe $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
  */
 
 #include "config.h"
@@ -29,7 +29,7 @@
 
 #define GUCHARMAP_SEARCH_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), gucharmap_search_dialog_get_type (), GucharmapSearchDialogPrivate))
 
-extern GdkCursor * _gucharmap_window_progress_cursor ();
+GdkCursor * _gucharmap_window_progress_cursor ();
 
 enum
 {
@@ -39,6 +39,7 @@ enum
 };
 
 static guint gucharmap_search_dialog_signals[NUM_SIGNALS] = { 0, 0 };
+static GObjectClass *parent_class;
 
 enum
 {
@@ -703,12 +704,12 @@ search_find_response (GtkDialog *dialog,
 }
 
 static void
-entry_changed (GtkEntry              *entry,
+entry_changed (GtkObject             *object,
                GucharmapSearchDialog *search_dialog)
 {
   GucharmapSearchDialogPrivate *priv = GUCHARMAP_SEARCH_DIALOG_GET_PRIVATE (search_dialog);
 
-  if (_entry_is_empty(entry))
+  if (_entry_is_empty (GTK_ENTRY (priv->entry)))
     {
       gtk_widget_set_sensitive (priv->prev_button, FALSE);
       gtk_widget_set_sensitive (priv->next_button, FALSE);
@@ -794,10 +795,12 @@ gucharmap_search_dialog_init (GucharmapSearchDialog *search_dialog)
   priv->whole_word_option = gtk_check_button_new_with_mnemonic (_("Match _whole word"));
   gtk_widget_show (priv->whole_word_option);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (search_dialog)->vbox), priv->whole_word_option, FALSE, FALSE, 0);
+  g_signal_connect (priv->whole_word_option, "toggled", G_CALLBACK (entry_changed), search_dialog);
 
   priv->annotations_option = gtk_check_button_new_with_mnemonic (_("Search in character _details"));
   gtk_widget_show (priv->annotations_option);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (search_dialog)->vbox), priv->annotations_option, FALSE, FALSE, 0);
+  g_signal_connect (priv->annotations_option, "toggled", G_CALLBACK (entry_changed), search_dialog);
 
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), priv->entry);
 
@@ -819,6 +822,8 @@ gucharmap_search_dialog_finalize (GObject *object)
 
   if (priv->search_state)
     gucharmap_search_state_free (priv->search_state);
+
+  parent_class->finalize (object);
 }
 
 static void
@@ -826,6 +831,8 @@ gucharmap_search_dialog_class_init (GucharmapSearchDialogClass *clazz)
 {
   g_type_class_add_private (clazz, sizeof (GucharmapSearchDialogPrivate));
 
+  parent_class = (GObjectClass *) g_type_class_peek_parent (clazz);
+
   G_OBJECT_CLASS (clazz)->finalize = gucharmap_search_dialog_finalize;
 
   clazz->search_start = NULL;
@@ -834,41 +841,16 @@ gucharmap_search_dialog_class_init (GucharmapSearchDialogClass *clazz)
   gucharmap_search_dialog_signals[SEARCH_START] =
       g_signal_new ("search-start", gucharmap_search_dialog_get_type (), G_SIGNAL_RUN_FIRST, 
                     G_STRUCT_OFFSET (GucharmapSearchDialogClass, search_start), NULL, NULL, 
-                    gucharmap_marshal_VOID__VOID, G_TYPE_NONE, 0);
+                    g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
   gucharmap_search_dialog_signals[SEARCH_FINISH] =
       g_signal_new ("search-finish", gucharmap_search_dialog_get_type (), G_SIGNAL_RUN_FIRST, 
                     G_STRUCT_OFFSET (GucharmapSearchDialogClass, search_finish), NULL, NULL, 
-                    gucharmap_marshal_VOID__UINT, G_TYPE_NONE, 1, G_TYPE_UINT);
+                    g_cclosure_marshal_VOID__UINT, G_TYPE_NONE, 1, G_TYPE_UINT);
 
-  gucharmap_intl_ensure_initialized ();
+  _gucharmap_intl_ensure_initialized ();
 }
 
-GType
-gucharmap_search_dialog_get_type (void)
-{
-  static GType t = 0;
-
-  if (t == 0)
-    {
-      static const GTypeInfo type_info =
-        {
-          sizeof (GucharmapSearchDialogClass),
-          NULL,
-          NULL,
-          (GClassInitFunc) gucharmap_search_dialog_class_init,
-          NULL,
-          NULL,
-          sizeof (GucharmapSearchDialog),
-          0,
-          (GInstanceInitFunc) gucharmap_search_dialog_init,
-          NULL
-        };
-
-      t = g_type_register_static (gtk_dialog_get_type (), "GucharmapSearchDialog", &type_info, 0);
-    }
-
-  return t;
-}
+G_DEFINE_TYPE (GucharmapSearchDialog, gucharmap_search_dialog, GTK_TYPE_DIALOG)
 
 GtkWidget * 
 gucharmap_search_dialog_new (GucharmapWindow *guw)
