@@ -1,4 +1,3 @@
-/* $Id: gucharmap-table.h 692 2004-02-01 00:17:34Z nlevitt $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -14,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
  */
 
 #ifndef GUCHARMAP_TABLE_H
@@ -25,6 +24,8 @@
 
 G_BEGIN_DECLS
 
+#define GUCHARMAP_TYPE_TABLE (gucharmap_table_get_type ())
+
 #define GUCHARMAP_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
                               gucharmap_table_get_type (), GucharmapTable))
 
@@ -39,36 +40,39 @@ struct _GucharmapTable
 {
   GtkHBox parent;
 
+  /* FIXME: remove all this crap when bumping the ABI version */
   /* rows and columns on a page */
-  gint rows, cols;
+  gint _unused_1, _unused_2;
 
-  GtkWidget *drawing_area;         /* GtkDrawingArea */
-  GdkPixmap *pixmap; 
+  GtkWidget *drawing_area;
+  GtkWidget *scrolled_window;
 
-  gchar *font_name;
-  PangoLayout *pango_layout;
+  gpointer _unused_4;
+  gpointer _unused_5;
 
-  gint page_first_cell;
-  gint active_cell;
-  gint old_page_first_cell;
-  gint old_active_cell;
+  gint _unused_6;
+  gint _unused_7;
+  gint _unused_8;
+  gint _unused_9;
 
   /* for the scrollbar */
-  GtkAdjustment *adjustment; 
-  gulong adjustment_changed_handler_id; 
-  GtkWidget *scrollbar;
+  gpointer _unused_10;
+  gulong _unused_11;
+  gpointer _unused_12;
 
-  GtkWidget *zoom_window;
-  GdkPixmap *zoom_pixmap;
-  gboolean zoom_mode_enabled;
+  gpointer _unused_13;
+  gpointer _unused_14;
+  gboolean _unused_15;
 
-  gboolean snap_pow2_enabled;
+  gboolean _unused_16;
 
   /* for dragging (#114534) */
-  gdouble click_x, click_y; 
+  gdouble _unused_17, _unused_18;
 
-  GucharmapCodepointList *codepoint_list;
-  gboolean codepoint_list_changed;
+  gpointer _unused_19;
+
+  gpointer _unused_20;
+  gboolean _unused_21;
 };
 
 struct _GucharmapTableClass
@@ -89,16 +93,14 @@ void gucharmap_table_set_active_character (GucharmapTable *chartable,
                                            gunichar uc);
 void gucharmap_table_zoom_enable (GucharmapTable *chartable);
 void gucharmap_table_zoom_disable (GucharmapTable *chartable);
-void gucharmap_table_identify_clipboard (GucharmapTable *chartable, 
-                                         GtkClipboard *clipboard);
 void gucharmap_table_grab_focus (GucharmapTable *chartable);
 void gucharmap_table_set_snap_pow2 (GucharmapTable *chartable, 
                                     gboolean snap);
 void gucharmap_table_set_codepoint_list (GucharmapTable         *chartable,
                                          GucharmapCodepointList *list);
+GucharmapCodepointList * gucharmap_table_get_codepoint_list (GucharmapTable         *chartable);
+gint gucharmap_table_get_active_cell (GucharmapTable *chartable);
 
 G_END_DECLS
 
 #endif  /* #ifndef GUCHARMAP_TABLE_H */
-
-
