@@ -1,4 +1,4 @@
-/* $Id: gucharmap-unicode-info.c,v 1.14 2005/11/29 12:06:30 behdad Exp $ */
+/* $Id: gucharmap-unicode-info.c 1493 2007-12-12 19:33:26Z chpe $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
  */
 
 #include "config.h"
@@ -43,18 +43,18 @@
 #define NCount (VCount * TCount)
 #define SCount (LCount * NCount)
 
-static const gchar * const JAMO_L_TABLE[] = {
+static const gchar JAMO_L_TABLE[][4] = {
   "G", "GG", "N", "D", "DD", "R", "M", "B", "BB",
-  "S", "SS", "", "J", "JJ", "C", "K", "T", "P", "H", NULL
+  "S", "SS", "", "J", "JJ", "C", "K", "T", "P", "H"
 };
 
-static const gchar * const JAMO_V_TABLE[] = {
+static const gchar JAMO_V_TABLE[][4] = {
   "A", "AE", "YA", "YAE", "EO", "E", "YEO", "YE", "O",
   "WA", "WAE", "OE", "YO", "U", "WEO", "WE", "WI",
   "YU", "EU", "YI", "I"
 };
 
-static const gchar * const JAMO_T_TABLE[] = {
+static const gchar JAMO_T_TABLE[][4] = {
   "", "G", "GG", "GS", "N", "NJ", "NH", "D", "L", "LG", "LM",
   "LB", "LS", "LT", "LP", "LH", "M", "B", "BS",
   "S", "SS", "NG", "J", "C", "K", "T", "P", "H"
@@ -65,6 +65,8 @@ gucharmap_get_unicode_name (gunichar wc)
 {
   static gchar buf[32];
 
+  _gucharmap_intl_ensure_initialized ();
+
   if ((wc >= 0x3400 && wc <= 0x4DB5) 
       || (wc >= 0x4e00 && wc <= 0x9fa5) 
       || (wc >= 0x20000 && wc <= 0x2A6D6))
@@ -115,6 +117,8 @@ gucharmap_get_unicode_name (gunichar wc)
 G_CONST_RETURN gchar *
 gucharmap_get_unicode_category_name (gunichar wc)
 {
+  _gucharmap_intl_ensure_initialized ();
+
   switch (gucharmap_unichar_type (wc))
     {
       case G_UNICODE_CONTROL: return _("Other, Control");
