@@ -1,4 +1,3 @@
-/* $Id: gucharmap-window.c 1357 2007-09-05 06:03:32Z behdad $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -14,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
  */
 
 #include "config.h"
@@ -23,9 +22,6 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#ifdef HAVE_GNOME
-# include <gnome.h>
-#endif
 #include "gucharmap-window.h"
 #include "gucharmap-mini-fontsel.h"
 #include "gucharmap-unicode-info.h"
@@ -33,6 +29,7 @@
 #include "gucharmap-block-chapters.h"
 #include "gucharmap-intl.h"
 #include "gucharmap-search-dialog.h"
+#include "gucharmap-settings.h"
 
 #ifndef ICON_PATH
 # define ICON_PATH ""
@@ -41,13 +38,6 @@
 #define GUCHARMAP_WINDOW_GET_PRIVATE(o) \
             (G_TYPE_INSTANCE_GET_PRIVATE ((o), gucharmap_window_get_type (), GucharmapWindowPrivate))
 
-typedef enum
-{
-  CHAPTERS_SCRIPT,
-  CHAPTERS_BLOCK
-}
-ChaptersMode;
-
 typedef struct _GucharmapWindowPrivate GucharmapWindowPrivate;
 
 struct _GucharmapWindowPrivate
@@ -290,29 +280,82 @@ font_default (GtkAction       *action,
 }
 
 static void
-snap_cols_pow2 (GtkAction 	 *action, 
+snap_cols_pow2 (GtkAction        *action, 
                 GucharmapWindow  *guw)
 {
-  gucharmap_table_set_snap_pow2 (guw->charmap->chartable,
-  				 gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)));
+  gboolean is_active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
+  gucharmap_table_set_snap_pow2 (guw->charmap->chartable, is_active);
+  gucharmap_settings_set_snap_pow2 (is_active);
 }
 
-#ifdef HAVE_GNOME
 static void
-help_contents (GtkAction *action,
-	       gpointer  data)
+open_url (GtkWindow *parent,
+          const char *url)
 {
   GError *error = NULL;
+  GdkScreen *screen;
+  char *command;
 
-  gnome_help_display ("gucharmap.xml", NULL, &error);
+  screen = gtk_widget_get_screen (GTK_WIDGET (parent));
 
-  if (error != NULL)
-    {
-      g_warning ("%s", error->message);
-      g_error_free (error);
+  command = g_strconcat ("gnome-open ", url, NULL);
+  gdk_spawn_command_line_on_screen (screen, command, &error);
+  g_free (command);
+
+  if (error) {
+    GtkWidget *d;
+
+    d = gtk_message_dialog_new (parent,
+                                GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                "%s", error->message);
+    g_signal_connect (d, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+    gtk_window_present (GTK_WINDOW (d));
+    g_error_free (error);
+  }
+}
+
+static void
+help_contents (GtkAction *action,
+               GtkWindow *window)
+{
+  const char *lang;
+  char *uri = NULL, *url;
+  guint i;
+ 
+  const char * const * langs = g_get_language_names ();
+  for (i = 0; langs[i]; i++) {
+    lang = langs[i];
+    if (strchr (lang, '.')) {
+      continue;
     }
+ 
+    uri = g_build_filename (DATADIR,
+                            "/gnome/help/gucharmap/",
+                            lang,
+                            "/gucharmap.xml",
+                            NULL);
+					
+    if (g_file_test (uri, G_FILE_TEST_EXISTS)) {
+      break;
+    }
+  }
+
+  if (!uri)
+    return;
+
+  url = g_strconcat ("ghelp://", uri, NULL);
+  open_url (window, url);
+  g_free (url);
+}
+
+static void
+about_open_url (GtkAboutDialog *about,
+                const char *link,
+                gpointer data)
+{
+  open_url (GTK_WINDOW (about), link);
 }
-#endif
 
 static void
 help_about (GtkAction       *action, 
@@ -348,7 +391,7 @@ help_about (GtkAction       *action,
        "the GNU General Public License and Unicode Copyright for more details."),
     N_("You should have received a copy of the GNU General Public License "
        "along with Gucharmap; if not, write to the Free Software Foundation, Inc., "
-       "59 Temple Place, Suite 330, Boston, MA  02111-1307  USA"),
+       "59 Temple Place, Suite 330, Boston, MA  02110-1301  USA"),
     N_("Also you should have received a copy of the Unicode Copyright along "
        "with Gucharmap; you can always find it at Unicode's website: "
        "http://www.unicode.org/copyright.html")
@@ -358,6 +401,8 @@ help_about (GtkAction       *action,
 			       _(license[2]), "\n\n", _(license[3]), "\n\n",
 			       _(license[4]), "\n\n", NULL);
 
+  gtk_about_dialog_set_url_hook (about_open_url, NULL, NULL);
+
   gtk_show_about_dialog (GTK_WINDOW (guw),
   			 "authors", authors,
 			 "comments", _("GNOME Character Map\n"
@@ -366,7 +411,7 @@ help_about (GtkAction       *action,
 				      "Copyright © 1991-2005 Unicode, Inc.",
 			 "documenters", documenters,
 			 "license", license_trans,
-			 "name", _("Gucharmap"),
+			 "program-name", _("Gucharmap"),
 			 "logo-icon-name", "gucharmap",
 			 "translator-credits", _("translator-credits"),
 			 "version", VERSION,
@@ -377,22 +422,26 @@ help_about (GtkAction       *action,
   g_free (license_trans);
 }
 
+/* FIXMEchpe: make these methods on the codepoint list! */
 static void
 prev_character (GtkAction       *action,
                 GucharmapWindow *guw)
 {
-  gint index = guw->charmap->chartable->active_cell;
-  gint start = index;
+  GucharmapCodepointList *codepoint_list;
+  gint index, start;
   gunichar wc;
 
+  start = index = gucharmap_table_get_active_cell (guw->charmap->chartable);
+  codepoint_list = gucharmap_table_get_codepoint_list (guw->charmap->chartable);
+
   do
     {
       index--;
 
       if (index < 0)
-        index = gucharmap_codepoint_list_get_last_index (guw->charmap->chartable->codepoint_list);
+        index = gucharmap_codepoint_list_get_last_index (codepoint_list);
 
-      wc = gucharmap_codepoint_list_get_char (guw->charmap->chartable->codepoint_list, index);
+      wc = gucharmap_codepoint_list_get_char (codepoint_list, index);
     }
   while ((!gucharmap_unichar_isdefined (wc) || !gucharmap_unichar_validate (wc)) && index != start);
 
@@ -403,18 +452,21 @@ static void
 next_character (GtkAction       *action,
                 GucharmapWindow *guw)
 {
-  gint index = guw->charmap->chartable->active_cell;
-  gint start = index;
+  GucharmapCodepointList *codepoint_list;
+  gint index, start;
   gunichar wc;
 
+  start = index = gucharmap_table_get_active_cell (guw->charmap->chartable);
+  codepoint_list = gucharmap_table_get_codepoint_list (guw->charmap->chartable);
+
   do
     {
       index++;
 
-      if (index > gucharmap_codepoint_list_get_last_index (guw->charmap->chartable->codepoint_list))
+      if (index > gucharmap_codepoint_list_get_last_index (codepoint_list))
         index = 0;
 
-      wc = gucharmap_codepoint_list_get_char (guw->charmap->chartable->codepoint_list, index);
+      wc = gucharmap_codepoint_list_get_char (codepoint_list, index);
     }
   while ((!gucharmap_unichar_isdefined (wc) || !gucharmap_unichar_validate (wc)) && index != start);
 
@@ -461,23 +513,53 @@ view_by (GtkAction        *action,
 	 GtkRadioAction   *radioaction,
          GucharmapWindow  *guw)
 {
+  ChaptersMode mode;
+
   switch (gtk_radio_action_get_current_value (radioaction))
     {
       case VIEW_BY_SCRIPT:
       	gucharmap_charmap_set_chapters (guw->charmap, GUCHARMAP_CHAPTERS (gucharmap_script_chapters_new ()));
 	chapters_set_labels (_("Next Script"), _("Previous Script"), guw);
+        mode = CHAPTERS_SCRIPT;
 	break;
       
       case VIEW_BY_BLOCK:
         gucharmap_charmap_set_chapters (guw->charmap, GUCHARMAP_CHAPTERS (gucharmap_block_chapters_new ()));
 	chapters_set_labels (_("Next Block"), _("Previous Block"), guw);
+        mode = CHAPTERS_BLOCK;
 	break;
       
       default:
         g_assert_not_reached ();
     }
+
+  gucharmap_settings_set_chapters_mode (mode);
 }
 
+#ifdef DEBUG_chpe
+static void
+move_to_next_screen_cb (GtkAction *action,
+                        GtkWidget *widget)
+{
+  GdkScreen *screen;
+  GdkDisplay *display;
+  int number_of_screens, screen_num;
+
+  screen = gtk_widget_get_screen (widget);
+  display = gdk_screen_get_display (screen);
+  screen_num = gdk_screen_get_number (screen);
+  number_of_screens =  gdk_display_get_n_screens (display);
+
+  if ((screen_num + 1) < number_of_screens) {
+    screen = gdk_display_get_screen (display, screen_num + 1);
+  } else {
+    screen = gdk_display_get_screen (display, 0);
+  }
+
+  gtk_window_set_screen (GTK_WINDOW (widget), screen);
+}
+#endif
+
 /* create the menu entries */
 /* tooltips are NULL because they are never actually shown in the program */
 
@@ -515,12 +597,15 @@ static const GtkActionEntry menu_entries[] =
   { "PreviousChapter", NULL, N_("Previous Script"), "<control>Page_Up",
     NULL, G_CALLBACK (prev_chapter) },
 
-#ifdef HAVE_GNOME
   { "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
     NULL, G_CALLBACK (help_contents) },
-#endif
   { "About", GTK_STOCK_ABOUT, N_("_About"), NULL,
-    NULL, G_CALLBACK (help_about) }
+    NULL, G_CALLBACK (help_about) },
+
+#ifdef DEBUG_chpe
+  { "MoveNextScreen", NULL, "Move window to next screen", NULL,
+    NULL, G_CALLBACK (move_to_next_screen_cb) },
+#endif
 };
 
 static const GtkRadioActionEntry radio_menu_entries [] =
@@ -535,6 +620,9 @@ static const char ui_info [] =
 "  <menubar name=\"MenuBar\">"
 "    <menu name=\"FileMenu\" action=\"File\">"
 "	 <menuitem name=\"FileQuitMenu\" action=\"Quit\" />"
+#ifdef DEBUG_chpe
+"        <menuitem action=\"MoveNextScreen\" />"
+#endif
 "    </menu>"
 "    <menu name=\"ViewMenu\" action=\"View\">"
 "	 <menuitem name=\"ViewByScriptMenu\" action=\"ByScript\" />"
@@ -559,9 +647,7 @@ static const char ui_info [] =
 "	 <menuitem name=\"GoPreviousChapterMenu\" action=\"PreviousChapter\" />"
 "    </menu>"
 "    <menu name=\"HelpMenu\" action=\"Help\">"
-#ifdef HAVE_GNOME
 "	 <menuitem name=\"HelpContentsMenu\" action=\"HelpContents\" />"
-#endif
 "	 <menuitem name=\"HelpAboutMenu\" action=\"About\" />"
 "    </menu>"
 "  </menubar>";
@@ -591,7 +677,7 @@ make_menu (GucharmapWindow *guw)
   g_object_unref (priv->accel_group);
 
   toggle_menu = gtk_toggle_action_new ( "SnapColumns",
-					_("Snap Columns to Power of Two"),
+					_("Snap _Columns to Power of Two"),
 					NULL,
 					NULL);
   g_signal_connect (G_OBJECT(toggle_menu), "toggled", G_CALLBACK (snap_cols_pow2), guw);
@@ -612,12 +698,14 @@ make_menu (GucharmapWindow *guw)
   gtk_action_group_add_radio_actions (priv->action_group,
   				      radio_menu_entries,
 				      G_N_ELEMENTS (radio_menu_entries),
-				      VIEW_BY_SCRIPT,
+				      gucharmap_settings_get_chapters_mode(),
 				      G_CALLBACK (view_by),
 				      guw);
 
   gtk_action_group_add_action (priv->action_group,
   			       GTK_ACTION (toggle_menu));
+  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (toggle_menu),
+                                gucharmap_settings_get_snap_pow2 ());
   switch (priv->chapters_mode)
     {
       case CHAPTERS_SCRIPT:
@@ -665,6 +753,7 @@ fontsel_changed (GucharmapMiniFontSelection *fontsel,
   gchar *font_name = gucharmap_mini_font_selection_get_font_name (fontsel);
 
   gucharmap_table_set_font (guw->charmap->chartable, font_name);
+  gucharmap_settings_set_font (font_name);
 
   g_free (font_name);
 }
@@ -718,9 +807,6 @@ make_text_to_copy (GucharmapWindow *guw)
   GtkWidget *button;
   GtkWidget *label;
   GtkWidget *hbox;
-  GtkTooltips *tooltips;
-
-  tooltips = gtk_tooltips_new ();
 
   hbox = gtk_hbox_new (FALSE, 6);
 
@@ -745,7 +831,7 @@ make_text_to_copy (GucharmapWindow *guw)
   g_signal_connect (G_OBJECT (priv->text_to_copy_entry), "changed",
                     G_CALLBACK (entry_changed_sensitize_button), button);
 
-  gtk_tooltips_set_tip (tooltips, button, _("Copy to the clipboard."), NULL);
+  gtk_widget_set_tooltip_text (button, _("Copy to the clipboard."));
 
   return hbox;
 }
@@ -839,7 +925,7 @@ gucharmap_window_init (GucharmapWindow *guw)
   priv->font_selection_visible = FALSE;
   priv->text_to_copy_visible = FALSE;
   priv->file_menu_visible = FALSE;
-  priv->chapters_mode = CHAPTERS_SCRIPT;
+  priv->chapters_mode = gucharmap_settings_get_chapters_mode ();
 
   priv->search_dialog = NULL;
 
@@ -880,36 +966,9 @@ gucharmap_window_class_init (GucharmapWindowClass *clazz)
   _gucharmap_intl_ensure_initialized ();
 }
 
-GType 
-gucharmap_window_get_type (void)
-{
-  static GType gucharmap_window_type = 0;
+G_DEFINE_TYPE (GucharmapWindow, gucharmap_window, GTK_TYPE_WINDOW)
 
-  if (! gucharmap_window_type)
-    {
-      static const GTypeInfo gucharmap_window_info =
-        {
-          sizeof (GucharmapWindowClass),
-          NULL,
-          NULL,
-          (GClassInitFunc) gucharmap_window_class_init,
-          NULL,
-          NULL,
-          sizeof (GucharmapWindow),
-          0,
-          (GInstanceInitFunc) gucharmap_window_init
-        };
-
-      gucharmap_window_type = g_type_register_static (GTK_TYPE_WINDOW,
-                                                      "GucharmapWindow",
-                                                      &gucharmap_window_info,
-                                                      0);
-    }
-
-  return gucharmap_window_type;
-}
-
-GtkWidget * 
+GtkWidget *
 gucharmap_window_new (void)
 {
   return GTK_WIDGET (g_object_new (gucharmap_window_get_type (), NULL));
